pub struct Cap {
pub cgroup: Option<u64>,
pub host: Option<u64>,
}Expand description
What this process is allowed to use.
Fields
cgroup: Option<u64>The cgroup limit in bytes, or None where there is no cgroup or no
limit set on it.
host: Option<u64>What the machine has in bytes, or None where it could not be asked.
Implementations