name_at

Function name_at 

pub fn name_at(at: usize) -> &'static str
The name of the command at at, which is index_of the other way round.

Panics

If at is past the end of the table, which only a caller that made the index up rather than getting it from index_of can manage.