pub fn at(i: u16) -> Option<&'static Spec>Expand description
The command at i, or None if there is none there.
The other half of lookup_index, and the only thing that should ever be
handed one of its answers.
pub fn at(i: u16) -> Option<&'static Spec>The command at i, or None if there is none there.
The other half of lookup_index, and the only thing that should ever be
handed one of its answers.